pub fn find_basic_blocks(chunk: &BytecodeChunk) -> Vec<BasicBlock>Expand description
Perform basic block decomposition of a chunk.
Returns the list of basic blocks in order of their start offset.
pub fn find_basic_blocks(chunk: &BytecodeChunk) -> Vec<BasicBlock>Perform basic block decomposition of a chunk.
Returns the list of basic blocks in order of their start offset.