pub struct BytecodeCompiler;Expand description
A simple compiler from common expression patterns to bytecode chunks.
Implementations
Sourceimpl BytecodeCompiler
impl BytecodeCompiler
Sourcepub fn compile_nat(n: u64) -> BytecodeChunk
pub fn compile_nat(n: u64) -> BytecodeChunk
Compile a chunk that simply pushes a natural number and halts.
Sourcepub fn compile_add(a: u64, b: u64) -> BytecodeChunk
pub fn compile_add(a: u64, b: u64) -> BytecodeChunk
Compile a chunk that adds two naturals and halts.
Sourcepub fn compile_if(cond: bool, then_val: u64, else_val: u64) -> BytecodeChunk
pub fn compile_if(cond: bool, then_val: u64, else_val: u64) -> BytecodeChunk
Compile a conditional: if cond then then_val else else_val.