FramedInterpreter

Struct FramedInterpreter 

pub struct FramedInterpreter {
    pub stack: Vec<StackValue>,
    pub locals: Vec<StackValue>,
    pub frames: Vec<CallFrame>,
    pub ip: usize,
    pub max_depth: usize,
}
An interpreter that manages a proper call frame stack.

Fields

stack: Vec<StackValue>

The operand stack.

locals: Vec<StackValue>

All local variables across all frames (flat layout).

frames: Vec<CallFrame>

Frame stack (innermost at the back).

ip: usize

Current instruction pointer.

max_depth: usize

Maximum frame depth (0 = unlimited).

Implementations

Source

impl FramedInterpreter

pub fn new() -> Self

Create a new framed interpreter.

pub fn with_max_depth(self, d: usize) -> Self

Set the maximum call depth.

pub fn push_frame( &mut self, return_ip: usize, fn_name: &str, ) -> Result<(), String>

Push a new call frame, saving return_ip and recording locals_base.

pub fn pop_frame(&mut self) -> Option<usize>

Pop the top call frame and restore the instruction pointer.

pub fn depth(&self) -> usize

Current call depth.

pub fn frame(&self, depth: usize) -> Option<&CallFrame>

Get a frame by depth (0 = innermost).

pub fn stack_trace(&self) -> String

Pretty-print the current call stack trace.

pub fn reset(&mut self)

Reset the interpreter to a clean state.