pub struct InlineCacheEntry {
pub call_ip: usize,
pub hit_count: u64,
pub last_target: Option<u32>,
pub is_monomorphic: bool,
}Expand description
A simple inline cache entry for a call site.
Fields
call_ip: usizeOpcode index of the call site.
hit_count: u64Number of times this call site has been observed.
last_target: Option<u32>The most recently observed target function position.
is_monomorphic: boolWhether this entry is considered monomorphic.
Implementations