PeepholeOptimizer

Struct PeepholeOptimizer 

pub struct PeepholeOptimizer {
    pub passes: usize,
}
A simple peephole optimizer for bytecode chunks.

Applies a fixed set of local rewriting rules to reduce unnecessary instructions.

Fields

passes: usize

Number of optimization passes to make.

Implementations

Source

impl PeepholeOptimizer

pub fn new(passes: usize) -> Self

Create a new peephole optimizer with passes iterations.

pub fn optimize(&self, chunk: &BytecodeChunk) -> BytecodeChunk

Optimize the given chunk, returning a new optimized chunk.