Closure

Struct Closure 

pub struct Closure {
    pub fn_ptr: FnPtr,
    pub arity: u16,
    pub env: Vec<RtObject>,
    pub name: Option<String>,
    pub is_recursive: bool,
    pub is_known: bool,
}
A runtime closure with captured environment.

The closure captures free variables in a flat array. The function body is represented by a FnPtr into the code table.

Fields

fn_ptr: FnPtr

Pointer to the function body.

arity: u16

Total arity (number of parameters the function expects).

env: Vec<RtObject>

Captured environment values.

name: Option<String>

Name of the closure (for debugging).

is_recursive: bool

Whether this closure is recursive.

is_known: bool

Whether this closure has been marked as a known function (can be called directly without going through the closure mechanism).

Implementations

Source

impl Closure

pub fn new(fn_ptr: FnPtr, arity: u16, env: Vec<RtObject>) -> Self

Create a new closure.

pub fn named( name: String, fn_ptr: FnPtr, arity: u16, env: Vec<RtObject>, ) -> Self

Create a closure with a name.

pub fn simple(fn_ptr: FnPtr, arity: u16) -> Self

Create a simple closure with no captured environment.

pub fn env_size(&self) -> usize

Number of captured environment variables.

pub fn get_env(&self, index: usize) -> Option<&RtObject>

Get a captured value by index.

pub fn set_env(&mut self, index: usize, value: RtObject) -> bool

Set a captured value by index.

pub fn extend_env(&mut self, values: &[RtObject])

Extend the environment with additional values.

pub fn set_recursive(&mut self)

Mark as recursive.

pub fn set_known(&mut self)

Mark as a known function.