FnPtr

Struct FnPtr 

pub struct FnPtr {
    pub index: u32,
    pub module_id: u16,
}
A function pointer in the runtime.

Functions are identified by an index into the global function table. This allows us to represent function pointers without actual raw pointers.

Fields

index: u32

Index into the global function table.

module_id: u16

Module that defines this function (for multi-module support).

Implementations

Source

impl FnPtr

pub fn new(index: u32) -> Self

Create a new function pointer.

pub fn with_module(index: u32, module_id: u16) -> Self

Create a function pointer with module ID.

pub fn null() -> Self

Null/invalid function pointer.

pub fn is_null(&self) -> bool

Check if this is a null pointer.