FunctionEntry

Struct FunctionEntry 

pub struct FunctionEntry {
    pub name: String,
    pub arity: u16,
    pub env_size: u16,
    pub convention: CallConvention,
    pub is_recursive: bool,
    pub is_builtin: bool,
    pub is_inlined: bool,
    pub frame_size: u16,
    pub param_names: Vec<String>,
}
An entry in the global function table.

Each compiled function has an entry that describes its properties.

Fields

name: String

The function’s name.

arity: u16

Total arity.

env_size: u16

Number of environment variables expected (for closures).

convention: CallConvention

Preferred call convention.

is_recursive: bool

Whether this function is recursive.

is_builtin: bool

Whether this function is a built-in.

is_inlined: bool

Whether this function has been inlined at all call sites.

frame_size: u16

Stack frame size (in words) needed for local variables.

param_names: Vec<String>

Parameter names (for debugging).

Implementations

Source

impl FunctionEntry

pub fn new(name: String, arity: u16) -> Self

Create a new function entry.

pub fn builtin(name: String, arity: u16) -> Self

Create a built-in function entry.