ArrayOps

Struct ArrayOps 

pub struct ArrayOps;
Operations on array objects.

Implementations

Source

impl ArrayOps

pub fn len(obj: &RtObject) -> Option<usize>

Get the length of an array.

pub fn is_empty(obj: &RtObject) -> Option<bool>

Check if an array is empty.

pub fn get(obj: &RtObject, index: usize) -> Option<RtObject>

Get an element by index.

pub fn set(obj: &RtObject, index: usize, value: RtObject) -> Option<RtObject>

Set an element by index (in-place if unique, otherwise copy).

pub fn push(obj: &RtObject, value: RtObject) -> Option<RtObject>

Push an element onto the end of an array.

pub fn pop(obj: &RtObject) -> Option<(RtObject, RtObject)>

Pop the last element from an array.

pub fn mk_array(size: usize, default: RtObject) -> RtObject

Create an array of the given size filled with a default value.

pub fn concat(a: &RtObject, b: &RtObject) -> Option<RtObject>

Concatenate two arrays.

pub fn slice(obj: &RtObject, start: usize, end: usize) -> Option<RtObject>

Slice an array.

pub fn reverse(obj: &RtObject) -> Option<RtObject>

Reverse an array.