FieldAccess

Struct FieldAccess 

pub struct FieldAccess;
Access fields of constructor objects.

Implementations

Source

impl FieldAccess

pub fn get_field(obj: &RtObject, field_index: usize) -> Option<RtObject>

Get a field of a constructor object by index.

pub fn set_field(obj: &RtObject, field_index: usize, value: RtObject) -> bool

Set a field of a constructor object by index (requires unique ownership).

pub fn get_ctor_index(obj: &RtObject) -> Option<u32>

Get the constructor index of an object.

pub fn num_fields(obj: &RtObject) -> Option<usize>

Get the number of fields of a constructor object.

pub fn get_scalar_field(obj: &RtObject, field_index: usize) -> Option<u64>

Get a scalar field of a constructor object.

pub fn proj_fst(obj: &RtObject) -> Option<RtObject>

Project a field from a Prod (pair) type.

pub fn proj_snd(obj: &RtObject) -> Option<RtObject>

Project the second field from a Prod (pair) type.