CowBox

Struct CowBox 

pub struct CowBox<T> { /* private fields */ }
A copy-on-write smart pointer.

CowBox<T> wraps a value that is shared (read-only) until a mutation is requested, at which point it copies the value to create a unique owner.

Implementations

Source

impl<T: Clone> CowBox<T>

pub fn new(value: T) -> Self

Create a new CowBox.

pub fn as_ref(&self) -> &T

Get a read-only reference.

pub fn as_mut(&mut self) -> &mut T

Get a mutable reference, copying if necessary.

pub fn was_copied(&self) -> bool

Check if a COW copy has been made.

pub fn is_unique(&self) -> bool

Check if this is the unique owner.

pub fn into_owned(self) -> T

Unwrap the value, cloning if not unique.