ParallelEval

Struct ParallelEval 

pub struct ParallelEval;
Parallel evaluation primitives.

Implementations

Source

impl ParallelEval

pub fn par_map(scheduler: &mut Scheduler, actions: Vec<RtObject>) -> Vec<TaskId>

Evaluate multiple independent tasks in parallel and return results.

pub fn par_pair( scheduler: &mut Scheduler, action_a: RtObject, action_b: RtObject, ) -> (TaskId, TaskId)

Spawn two tasks and combine their results.

pub fn when_all( scheduler: &mut Scheduler, deps: Vec<TaskId>, continuation: RtObject, ) -> TaskId

Create a task that depends on the completion of all given tasks.

pub fn barrier( scheduler: &mut Scheduler, dep_actions: Vec<RtObject>, continuation: RtObject, ) -> (Vec<TaskId>, TaskId)

Create a barrier: spawn a continuation after all deps complete.