pub struct PreemptionSimulator {
pub time_slice: u64,
pub ticks_used: u64,
pub preemptions: u64,
pub active_task: Option<TaskId>,
}Expand description
Simulates preemptive scheduling by tracking time slices.
Fields
time_slice: u64Time slice in ticks per task before forced preemption.
ticks_used: u64Current tick within the slice for the active task.
preemptions: u64Total preemptions performed.
active_task: Option<TaskId>Currently active task.
Implementations
Sourceimpl PreemptionSimulator
impl PreemptionSimulator
Sourcepub fn set_active(&mut self, id: TaskId)
pub fn set_active(&mut self, id: TaskId)
Assign the active task.