Rope

Struct Rope 

pub struct Rope { /* private fields */ }
A rope data structure for efficient large string construction.

A rope is a binary tree of string slices that supports O(log n) concatenation. Flattening to a String is O(n).

Implementations

Source

impl Rope

pub fn new() -> Self

Create an empty rope.

pub fn from_str(s: &str) -> Self

Create a rope from a string.

pub fn len(&self) -> usize

Total byte length.

pub fn is_empty(&self) -> bool

Whether the rope is empty.

pub fn concat(self, other: Rope) -> Rope

Concatenate two ropes.

pub fn append_str(self, s: &str) -> Rope

Append a string slice to the rope.

pub fn collect_string(&self) -> String

Flatten the rope into a String.

Note: This uses the Display implementation which performs the same in-order traversal of the rope tree.

pub fn depth(&self) -> usize

Depth of the rope tree (for balance diagnostics).