Auto-generated module
🤖 Generated with SplitRS
Structs
- Basic
Block - A basic block: a maximal sequence of non-branching instructions.
- Bytecode
Chunk - A named sequence of opcodes.
- Bytecode
Compiler - A simple compiler from common expression patterns to bytecode chunks.
- Call
Frame - A saved call frame for nested function calls.
- Chunk
Builder - A DSL-style builder for constructing bytecode chunks.
- Chunk
Stats - Statistics about a bytecode chunk.
- Constant
Folder - A more comprehensive constant folding pass that folds sequences of constant push + arithmetic/logic instructions into a single Push.
- Dead
Code Eliminator - Remove instructions that can never be executed.
- Encoded
Instruction - Compact binary encoding of a single opcode.
- Framed
Interpreter - An interpreter that manages a proper call frame stack.
- Inline
Cache - A per-chunk inline cache.
- Inline
Cache Entry - A simple inline cache entry for a call site.
- Interpreter
- A simple stack-based bytecode interpreter.
- Liveness
Info - Result of liveness analysis for a single chunk.
- Opcode
Info - A dispatch table mapping opcode tags to handler descriptions.
- Opcode
Profile - Counts how many times each opcode type was executed.
- Peephole
Optimizer - A simple peephole optimizer for bytecode chunks.
- Profiling
Interpreter - An interpreter variant that tracks opcode profiling information.
Enums
- Call
Result - Result of applying a call convention.
- Opcode
- A single bytecode instruction.
- Stack
Value - A value on the interpreter stack.