pub struct FnPtr {
pub index: u32,
pub module_id: u16,
}Expand description
A function pointer in the runtime.
Functions are identified by an index into the global function table. This allows us to represent function pointers without actual raw pointers.
Fields
index: u32Index into the global function table.
module_id: u16Module that defines this function (for multi-module support).
Implementations