pub struct FunctionEntry {
pub name: String,
pub arity: u16,
pub env_size: u16,
pub convention: CallConvention,
pub is_recursive: bool,
pub is_builtin: bool,
pub is_inlined: bool,
pub frame_size: u16,
pub param_names: Vec<String>,
}Expand description
An entry in the global function table.
Each compiled function has an entry that describes its properties.
Fields
name: StringThe function’s name.
arity: u16Total arity.
env_size: u16Number of environment variables expected (for closures).
convention: CallConventionPreferred call convention.
is_recursive: boolWhether this function is recursive.
is_builtin: boolWhether this function is a built-in.
is_inlined: boolWhether this function has been inlined at all call sites.
frame_size: u16Stack frame size (in words) needed for local variables.
param_names: Vec<String>Parameter names (for debugging).
Implementations