pub struct FutureChain<T> { /* private fields */ }Expand description
A chain of lazy computations that can be built up and then forced.
Each step maps the previous value to the next. This is a simplified synchronous “future” / continuation chain.
Implementations
Sourceimpl<T: 'static> FutureChain<T>
impl<T: 'static> FutureChain<T>
Sourcepub fn step_count(&self) -> usize
pub fn step_count(&self) -> usize
Number of steps in the chain.